pub fn append_trend_run(
history: TrendHistory,
run: TrendRun,
max_runs: Option<usize>,
) -> TrendHistoryExpand description
Appends a run to history and optionally trims to max_runs newest entries.
pub fn append_trend_run(
history: TrendHistory,
run: TrendRun,
max_runs: Option<usize>,
) -> TrendHistoryAppends a run to history and optionally trims to max_runs newest entries.