pub struct FalsePositiveBaseline {
pub schema: String,
pub entries: Vec<FalsePositiveEntry>,
}Fields
schema: Stringentries: Vec<FalsePositiveEntry>Trait Implementations
Sourceimpl Clone for FalsePositiveBaseline
impl Clone for FalsePositiveBaseline
Sourcefn clone(&self) -> FalsePositiveBaseline
fn clone(&self) -> FalsePositiveBaseline
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FalsePositiveBaseline
impl Debug for FalsePositiveBaseline
Sourceimpl Default for FalsePositiveBaseline
impl Default for FalsePositiveBaseline
Sourceimpl<'de> Deserialize<'de> for FalsePositiveBaseline
impl<'de> Deserialize<'de> for FalsePositiveBaseline
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FalsePositiveBaseline
impl JsonSchema for FalsePositiveBaseline
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FalsePositiveBaseline
impl PartialEq for FalsePositiveBaseline
Sourceimpl Serialize for FalsePositiveBaseline
impl Serialize for FalsePositiveBaseline
impl Eq for FalsePositiveBaseline
impl StructuralPartialEq for FalsePositiveBaseline