pub struct FalsePositiveEntry {
pub fingerprint: String,
pub rule_id: String,
pub path: String,
pub line: u32,
pub note: Option<String>,
}Fields
fingerprint: Stringrule_id: Stringpath: Stringline: u32note: Option<String>Trait Implementations
Sourceimpl Clone for FalsePositiveEntry
impl Clone for FalsePositiveEntry
Sourcefn clone(&self) -> FalsePositiveEntry
fn clone(&self) -> FalsePositiveEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FalsePositiveEntry
impl Debug for FalsePositiveEntry
Sourceimpl<'de> Deserialize<'de> for FalsePositiveEntry
impl<'de> Deserialize<'de> for FalsePositiveEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FalsePositiveEntry
impl JsonSchema for FalsePositiveEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FalsePositiveEntry
impl PartialEq for FalsePositiveEntry
Sourceimpl Serialize for FalsePositiveEntry
impl Serialize for FalsePositiveEntry
impl Eq for FalsePositiveEntry
impl StructuralPartialEq for FalsePositiveEntry