pub struct TrendDelta {
pub findings: i64,
pub info: i64,
pub warn: i64,
pub error: i64,
pub suppressed: i64,
}Fields
findings: i64info: i64warn: i64error: i64suppressed: i64Trait Implementations
Sourceimpl Clone for TrendDelta
impl Clone for TrendDelta
Sourcefn clone(&self) -> TrendDelta
fn clone(&self) -> TrendDelta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrendDelta
impl Debug for TrendDelta
Sourceimpl<'de> Deserialize<'de> for TrendDelta
impl<'de> Deserialize<'de> for TrendDelta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrendDelta
impl JsonSchema for TrendDelta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TrendDelta
impl PartialEq for TrendDelta
Sourceimpl Serialize for TrendDelta
impl Serialize for TrendDelta
impl Eq for TrendDelta
impl StructuralPartialEq for TrendDelta