pub struct TrendHistory {
pub schema: String,
pub runs: Vec<TrendRun>,
}Fields
schema: Stringruns: Vec<TrendRun>Trait Implementations
Sourceimpl Clone for TrendHistory
impl Clone for TrendHistory
Sourcefn clone(&self) -> TrendHistory
fn clone(&self) -> TrendHistory
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrendHistory
impl Debug for TrendHistory
Sourceimpl Default for TrendHistory
impl Default for TrendHistory
Sourceimpl<'de> Deserialize<'de> for TrendHistory
impl<'de> Deserialize<'de> for TrendHistory
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrendHistory
impl JsonSchema for TrendHistory
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TrendHistory
impl PartialEq for TrendHistory
Sourceimpl Serialize for TrendHistory
impl Serialize for TrendHistory
impl Eq for TrendHistory
impl StructuralPartialEq for TrendHistory