pub struct TrendRun {
pub started_at: String,
pub ended_at: String,
pub duration_ms: u64,
pub base: String,
pub head: String,
pub scope: Scope,
pub status: VerdictStatus,
pub counts: VerdictCounts,
pub files_scanned: u32,
pub lines_scanned: u32,
pub findings: u32,
}Fields
started_at: Stringended_at: Stringduration_ms: u64base: Stringhead: Stringscope: Scopestatus: VerdictStatuscounts: VerdictCountsfiles_scanned: u32lines_scanned: u32findings: u32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for TrendRun
impl<'de> Deserialize<'de> for TrendRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrendRun
impl JsonSchema for TrendRun
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for TrendRun
impl StructuralPartialEq for TrendRun