pub struct TrendSummary {
pub run_count: u32,
pub totals: VerdictCounts,
pub total_findings: u32,
pub latest: Option<TrendRun>,
pub delta_from_previous: Option<TrendDelta>,
}Fields
run_count: u32totals: VerdictCountstotal_findings: u32latest: Option<TrendRun>delta_from_previous: Option<TrendDelta>Trait Implementations
Sourceimpl Clone for TrendSummary
impl Clone for TrendSummary
Sourcefn clone(&self) -> TrendSummary
fn clone(&self) -> TrendSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrendSummary
impl Debug for TrendSummary
Sourceimpl<'de> Deserialize<'de> for TrendSummary
impl<'de> Deserialize<'de> for TrendSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrendSummary
impl JsonSchema for TrendSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TrendSummary
impl PartialEq for TrendSummary
Sourceimpl Serialize for TrendSummary
impl Serialize for TrendSummary
impl Eq for TrendSummary
impl StructuralPartialEq for TrendSummary